Imports System
Imports System.Data
Imports NorthwindWinFormViewsDynamic_VB.DataLayer
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject
Imports NorthwindWinFormViewsDynamic_VB.Models
Imports System.Runtime.InteropServices

Namespace BusinessObject.Base

     ''' <summary>
     ''' Base class for CurrentProductList.  Do not make changes to this class,
     ''' instead, put additional code in the CurrentProductList class
     ''' </summary>
     Public Class CurrentProductListBase
         ' private members
         Private _productID As Integer
         Private _productName As String

         ''' <summary>
         ''' Gets or Sets ProductID
         ''' </summary>
         Public Property ProductID() As Integer
             Get
                 Return _productID
             End Get
             Set(ByVal value As Integer)
                 _productID = value
             End Set
         End Property

         ''' <summary>
         ''' Gets or Sets ProductName
         ''' </summary>
         Public Property ProductName() As String
             Get
                 Return _productName
             End Get
             Set(ByVal value As String)
                 _productName = value
             End Set
         End Property


         ''' <summary>
         ''' Constructor
         ''' </summary>
         Public Sub New()
         End Sub

         ''' <summary>
         ''' Gets the total number of records in the CurrentProductList table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Return CurrentProductListDataLayer.GetRecordCount()
         End Function

         ''' <summary>
         ''' Selects records as a collection (List) of CurrentProductList sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex
         ''' </summary>
         Public Shared Function SelectSkipAndTake(rows As Integer, startRowIndex As Integer, <Out()> ByRef totalRowCount As Integer, sortByExpression As String) As CurrentProductListCollection
             totalRowCount = GetRecordCount()
             sortByExpression = GetSortExpression(sortByExpression)

             Return CurrentProductListDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Selects records as a collection (List) of CurrentProductList sorted by the sortByExpression and returns the rows (# of records) starting from the startRowIndex.  Use for non model-binded gridview control.  Does not return total row count.
         ''' </summary>
         Public Shared Function SelectSkipAndTake(rows As Integer, startRowIndex As Integer, sortByExpression As String) As CurrentProductListCollection
             sortByExpression = GetSortExpression(sortByExpression)
             Return CurrentProductListDataLayer.SelectSkipAndTake(sortByExpression, startRowIndex, rows)
         End Function

         Private Shared Function GetSortExpression(sortByExpression As String) As String
             If [String].IsNullOrEmpty(sortByExpression) Or sortByExpression = " asc" Then
                 sortByExpression = "ProductID"
             Else If sortByExpression.Contains(" asc") Then
                 sortByExpression = sortByExpression.Replace(" asc", "")
             End If

             Return sortByExpression
         End Function

         ''' <summary>
         ''' Compares ProductID used for sorting
         ''' </summary>
         Public Shared ByProductID As Comparison(Of CurrentProductList) =
         Function(ByVal x As CurrentProductList, ByVal y As CurrentProductList)
             Return x.ProductID.CompareTo(y.ProductID)
         End Function

         ''' <summary>
         ''' Compares ProductName used for sorting
         ''' </summary>
         Public Shared ByProductName As Comparison(Of CurrentProductList) =
         Function(ByVal x As CurrentProductList, ByVal y As CurrentProductList)
             Dim value1 As String = If(x.ProductName, String.Empty)
             Dim value2 As String = If(y.ProductName, String.Empty)
             Return value1.CompareTo(value2)
         End Function

     End Class
End Namespace
