Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for CurrentProductListDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the CurrentProductListDataLayer class
     ''' </summary>
     Public Class CurrentProductListDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As CurrentProductListCollection
              Dim objCurrentProductListCol As CurrentProductListCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objCurrentProductListCol = New CurrentProductListCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objCurrentProductList As CurrentProductList = CreateCurrentProductListFromDataRowShared(dr)
                                      objCurrentProductListCol.Add(objCurrentProductList)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objCurrentProductListCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the CurrentProductList table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = CurrentProductListSql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects CurrentProductList records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As CurrentProductListCollection
             Dim dynamicSqlScript As String = CurrentProductListSql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a CurrentProductList object from the passed data row
         ''' </summary>
         Private Shared Function CreateCurrentProductListFromDataRowShared(dr As DataRow) As CurrentProductList
             Dim objCurrentProductList As CurrentProductList = New CurrentProductList()


             If Not DbNull.Value.Equals(dr("ProductID")) Then
                 objCurrentProductList.ProductID = DirectCast(dr("ProductID"), Integer)
             Else
                 objCurrentProductList.ProductID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductName")) Then
                 objCurrentProductList.ProductName = dr("ProductName").ToString()
             Else
                 objCurrentProductList.ProductName = Nothing
             End If

             Return objCurrentProductList
         End Function
     End Class
End Namespace
