Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports System.Configuration
Imports NorthwindWinFormViewsDynamic_VB.BusinessObject

Namespace DataLayer.Base
     ''' <summary>
     ''' Base class for SalesByCategoryDataLayer.  Do not make changes to this class,
     ''' instead, put additional code in the SalesByCategoryDataLayer class
     ''' </summary>
     Public Class SalesByCategoryDataLayerBase

         ' constructor
         Public Sub New()
         End Sub

         Public Shared Function SelectShared(dynamicSqlScript As String, param As String, paramValue As Object, Optional ByVal sortByExpression As String = Nothing, Optional ByVal startRowIndex As Integer? = Nothing, Optional ByVal rows As Integer? = Nothing) As SalesByCategoryCollection
              Dim objSalesByCategoryCol As SalesByCategoryCollection = Nothing

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      ' select, skip, take, sort parameters
                      If Not [String].IsNullOrEmpty(sortByExpression) AndAlso startRowIndex IsNot Nothing AndAlso rows IsNot Nothing Then
                          command.Parameters.AddWithValue("@start", startRowIndex.Value)
                          command.Parameters.AddWithValue("@numberOfRows", rows.Value)
                          command.Parameters.AddWithValue("@sortByExpression", sortByExpression)
                      End If

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  objSalesByCategoryCol = New SalesByCategoryCollection()

                                  For Each dr As DataRow In dt.Rows
                                      Dim objSalesByCategory As SalesByCategory = CreateSalesByCategoryFromDataRowShared(dr)
                                      objSalesByCategoryCol.Add(objSalesByCategory)
                                  Next
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return objSalesByCategoryCol
         End Function

         ''' <summary>
         ''' Gets the total number of records in the SalesByCategory table
         ''' </summary>
         Public Shared Function GetRecordCount() As Integer
             Dim sql As String = SalesByCategorySql.GetRecordCount()
             Return GetRecordCountShared(Nothing, Nothing, Nothing, False, sql)
         End Function

         Public Shared Function GetRecordCountShared(Optional ByVal storedProcName As String = Nothing, Optional ByVal param As String = Nothing, Optional ByVal paramValue As Object = Nothing, Optional ByVal isUseStoredProc As Boolean = True, Optional ByVal dynamicSqlScript As String = Nothing) As Integer
              Dim recordCount As Integer = 0

              Using connection As New SqlConnection(ConfigurationManager.ConnectionStrings("ConnectionString").ConnectionString)
                  connection.Open()

                  Using command As New SqlCommand(dynamicSqlScript, connection)
                      command.CommandType = CommandType.Text

                      Using da As New SqlDataAdapter(command)
                          Dim dt As New DataTable()
                          da.Fill(dt)

                          If dt IsNot Nothing Then
                              If dt.Rows.Count > 0 Then
                                  recordCount = DirectCast(dt.Rows(0)("RecordCount"), Integer)
                              End If
                          End If
                      End Using
                  End Using
              End Using

              Return recordCount
         End Function

         ''' <summary>
         ''' Selects SalesByCategory records sorted by the sortByExpression and returns records from the startRowIndex with rows (# of records)
         ''' </summary>
         Public Shared Function SelectSkipAndTake(sortByExpression As String, startRowIndex As Integer, rows As Integer) As SalesByCategoryCollection
             Dim dynamicSqlScript As String = SalesByCategorySql.SelectSkipAndTake()
             Return SelectShared(dynamicSqlScript, Nothing, Nothing, sortByExpression, startRowIndex, rows)
         End Function

         ''' <summary>
         ''' Creates a SalesByCategory object from the passed data row
         ''' </summary>
         Private Shared Function CreateSalesByCategoryFromDataRowShared(dr As DataRow) As SalesByCategory
             Dim objSalesByCategory As SalesByCategory = New SalesByCategory()


             If Not DbNull.Value.Equals(dr("CategoryID")) Then
                 objSalesByCategory.CategoryID = DirectCast(dr("CategoryID"), Integer)
             Else
                 objSalesByCategory.CategoryID = Nothing
             End If

             If Not DbNull.Value.Equals(dr("CategoryName")) Then
                 objSalesByCategory.CategoryName = dr("CategoryName").ToString()
             Else
                 objSalesByCategory.CategoryName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductName")) Then
                 objSalesByCategory.ProductName = dr("ProductName").ToString()
             Else
                 objSalesByCategory.ProductName = Nothing
             End If

             If Not DbNull.Value.Equals(dr("ProductSales")) Then
                 objSalesByCategory.ProductSales = DirectCast(dr("ProductSales"), Decimal)
             Else
                 objSalesByCategory.ProductSales = Nothing
             End If

             Return objSalesByCategory
         End Function
     End Class
End Namespace
